The fragility index is the smallest number of grid dimensions (prompt,
model, label order, temperature) that must change from the reference
cell before the conclusion – as defined by the flip rule – changes.
Inf when no cell in the grid flips, which is a statement about this
grid, not a proof of robustness.
Usage
audit_fragility(audit, reference = 1L, flip = sign_flip())Arguments
- audit
An
audit_run()result.- reference
Reference cell (default 1).
- flip
A flip rule (see flip_rules); default
sign_flip().